==> printjs-1.0.2.tar.gz: printjs/js/printjs.js <==
(function ($, Drupal, drupalSettings) {

  'use strict';

  Drupal.behaviors.printjs = {
    attach: function (context, settings) {
      let eventClick = '.btn-print';
      let printSelector = 'print';
      if (drupalSettings.hasOwnProperty('printjs')) {
        if (drupalSettings.printjs.btn_selector_print) {
          eventClick += ' ,' + drupalSettings.printjs.btn_selector_print;
        }
        if (drupalSettings.printjs.printjs_id) {
          printSelector = drupalSettings.printjs.printjs_id.replace('#','');
        }
        // Add print wrapper.
        if (drupalSettings.printjs.print_parent_selector) {
          $('#' + printSelector).once().wrap('<div class="wrapper-print" id="wrapper-print"></div>');
        }
      }
      $(eventClick, context).once('printjs').each(function () {
        init(eventClick, printSelector);
      });

      function init(eventClick, printSelector) {

        // Check event onclick.
        $(eventClick).once().on('click', function () {
          let css = [];
          let config = $(this).data();
          $("head").find("link[rel='stylesheet']").attr("href", function (i, value) {
            css.push(value);
          });
          config.css = css;
          if (!config.printable.length) {
            config.printable = printSelector;
          }
          if (!config.type.length) {
            config.type = 'html';
          }

          if (!$('#' + config.printable).length) {
            if ($('main').length) {
              $('main').attr('id', config.printable);
            } else {
              $('body').attr('id', config.printable);
            }
          }
          // Print parent #print.
          if (drupalSettings.hasOwnProperty('printjs') && drupalSettings.printjs.print_parent_selector) {
            config.printable = "wrapper-print";
          }

          if (config.printable) {
            printJS(config);
          } else {
            window.print();
          }
        });
      }
    }
  }
}(jQuery, Drupal, drupalSettings));

==> printjs-1.0.4.tar.gz: printjs/js/printjs.js <==
(function ($, Drupal, drupalSettings, once) {

  'use strict';

  Drupal.behaviors.printjs = {
    attach: function (context, settings) {
      let eventClick = '.btn-print';
      let printSelector = 'print';
      if (drupalSettings.hasOwnProperty('printjs')) {
        if (drupalSettings.printjs.btn_selector_print) {
          eventClick += ' ,' + drupalSettings.printjs.btn_selector_print;
        }
        if (drupalSettings.printjs.printjs_id) {
          printSelector = drupalSettings.printjs.printjs_id.replace('#','');
        }
        // Add print wrapper.
        if (drupalSettings.printjs.print_parent_selector) {
          $(once(printSelector, '#' + printSelector, context)).wrap('<div class="wrapper-print" id="wrapper-print"></div>');
        }
      }
      $(once('printjs', eventClick, context)).each(function () {
        init(eventClick, printSelector);
      });

      function init(eventClick, printSelector) {

        // Check event onclick.
        $(eventClick).on('click', function () {
          let css = [];
          let config = $(this).data();
          $("head").find("link[rel='stylesheet']").attr("href", function (i, value) {
            css.push(value);
          });
          config.css = css;
          if (!config.printable.length) {
            config.printable = printSelector;
          }
          if (!config.type.length) {
            config.type = 'html';
          }

          if (!$('#' + config.printable).length) {
            if ($('main').length) {
              $('main').attr('id', config.printable);
            } else {
              $('body').attr('id', config.printable);
            }
          }
          // Print parent #print.
          if (drupalSettings.hasOwnProperty('printjs') && drupalSettings.printjs.print_parent_selector) {
            config.printable = "wrapper-print";
          }

          if (config.printable) {
            printJS(config);
          } else {
            window.print();
          }
        });
      }
    }
  }
}(jQuery, Drupal, drupalSettings, once));
